@@ -341,6 +341,29 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[], (doc)::a: !horse [a, b]\nb: !goat [b]\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "Keep anchors",
+		document:    "a: &horse [1]",
+		expression:  `.a += 2`,
+		expected: []string{
+			"D0, P[], (doc)::a: &horse [1, 2]\n",
+		},
+	},
+	{
+		skipDoc:       true,
+		description:   "Add sequence to map",
+		document:      "a: {x: cool}",
+		expression:    `.a += [2]`,
+		expectedError: "!!seq () cannot be added to a !!map (a)",
+	},
+	{
+		skipDoc:       true,
+		description:   "Add sequence to scalar",
+		document:      "a: cool",
+		expression:    `.a += [2]`,
+		expectedError: "!!seq () cannot be added to a !!str (a)",
+	},
 }
 
 func TestAddOperatorScenarios(t *testing.T) {
